# eric7.Project.UserPropertiesDialog

Module implementing the user specific project properties dialog.

### Global Attributes

None

### Classes

UserPropertiesDialog | Class implementing the user specific project properties dialog.

### Functions

None

## UserPropertiesDialog

Class implementing the user specific project properties dialog.

### Derived from

QDialog, Ui_UserPropertiesDialog

### Class Attributes

None

### Class Methods

None

### Methods

UserPropertiesDialog | Constructor
storeData | Public method to store the entered/modified data.

### Static Methods

None

#### UserPropertiesDialog (Constructor)

UserPropertiesDialog(project, parent=None, name=None)

Constructor

project (Project)
  reference to the project object
parent (QWidget)
  parent widget of this dialog
name (str)
  name of this dialog

#### UserPropertiesDialog.storeData

storeData()

Public method to store the entered/modified data.

Up